@@ -11,7 +11,7 @@ import (
 	"github.com/rubyist/tracerx"
 )
 
-var missingCallbackErr = errors.New("No callback given")
+var missingCallbackErr = errors.New("no callback given")
 
 // IsCallbackMissing returns a boolean indicating whether the error is reporting
 // that a GitScanner is missing a required GitScannerCallback.
@@ -68,7 +68,7 @@ func (s *GitScanner) RemoteForPush(r string) error {
 	defer s.mu.Unlock()
 
 	if len(s.remote) > 0 && s.remote != r {
-		return fmt.Errorf("Trying to set remote to %q, already set to %q", r, s.remote)
+		return fmt.Errorf("trying to set remote to %q, already set to %q", r, s.remote)
 	}
 
 	s.remote = r
@@ -88,11 +88,30 @@ func (s *GitScanner) ScanRangeToRemote(left, right string, cb GitScannerFoundPoi
 	s.mu.Lock()
 	if len(s.remote) == 0 {
 		s.mu.Unlock()
-		return fmt.Errorf("Unable to scan starting at %q: no remote set.", left)
+		return fmt.Errorf("unable to scan starting at %q: no remote set", left)
 	}
 	s.mu.Unlock()
 
-	return scanLeftRightToChan(s, callback, left, right, s.cfg.OSEnv(), s.opts(ScanRangeToRemoteMode))
+	return scanLeftRightToChan(s, callback, left, right, s.cfg.GitEnv(), s.cfg.OSEnv(), s.opts(ScanRangeToRemoteMode))
+}
+
+// ScanMultiRangeToRemote scans through all commits starting at the left ref but
+// not including the right ref (if given) that the given remote does not have.
+// See RemoteForPush().
+func (s *GitScanner) ScanMultiRangeToRemote(left string, rights []string, cb GitScannerFoundPointer) error {
+	callback, err := firstGitScannerCallback(cb, s.FoundPointer)
+	if err != nil {
+		return err
+	}
+
+	s.mu.Lock()
+	if len(s.remote) == 0 {
+		s.mu.Unlock()
+		return fmt.Errorf("unable to scan starting at %q: no remote set", left)
+	}
+	s.mu.Unlock()
+
+	return scanMultiLeftRightToChan(s, callback, left, rights, s.cfg.GitEnv(), s.cfg.OSEnv(), s.opts(ScanRangeToRemoteMode))
 }
 
 // ScanRefs through all commits reachable by refs contained in "include" and
@@ -105,7 +124,7 @@ func (s *GitScanner) ScanRefs(include, exclude []string, cb GitScannerFoundPoint
 
 	opts := s.opts(ScanRefsMode)
 	opts.SkipDeletedBlobs = false
-	return scanRefsToChan(s, callback, include, exclude, s.cfg.OSEnv(), opts)
+	return scanRefsToChan(s, callback, include, exclude, s.cfg.GitEnv(), s.cfg.OSEnv(), opts)
 }
 
 // ScanRefRange scans through all commits from the given left and right refs,
@@ -118,7 +137,7 @@ func (s *GitScanner) ScanRefRange(left, right string, cb GitScannerFoundPointer)
 
 	opts := s.opts(ScanRefsMode)
 	opts.SkipDeletedBlobs = false
-	return scanLeftRightToChan(s, callback, left, right, s.cfg.OSEnv(), opts)
+	return scanLeftRightToChan(s, callback, left, right, s.cfg.GitEnv(), s.cfg.OSEnv(), opts)
 }
 
 // ScanRefWithDeleted scans through all objects in the given ref, including
@@ -137,7 +156,7 @@ func (s *GitScanner) ScanRef(ref string, cb GitScannerFoundPointer) error {
 
 	opts := s.opts(ScanRefsMode)
 	opts.SkipDeletedBlobs = true
-	return scanLeftRightToChan(s, callback, ref, "", s.cfg.OSEnv(), opts)
+	return scanLeftRightToChan(s, callback, ref, "", s.cfg.GitEnv(), s.cfg.OSEnv(), opts)
 }
 
 // ScanAll scans through all objects in the git repository.
@@ -149,7 +168,7 @@ func (s *GitScanner) ScanAll(cb GitScannerFoundPointer) error {
 
 	opts := s.opts(ScanAllMode)
 	opts.SkipDeletedBlobs = false
-	return scanLeftRightToChan(s, callback, "", "", s.cfg.OSEnv(), opts)
+	return scanLeftRightToChan(s, callback, "", "", s.cfg.GitEnv(), s.cfg.OSEnv(), opts)
 }
 
 // ScanTree takes a ref and returns WrappedPointer objects in the tree at that
@@ -160,7 +179,7 @@ func (s *GitScanner) ScanTree(ref string) error {
 	if err != nil {
 		return err
 	}
-	return runScanTree(callback, ref, s.Filter, s.cfg.OSEnv())
+	return runScanTree(callback, ref, s.Filter, s.cfg.GitEnv(), s.cfg.OSEnv())
 }
 
 // ScanUnpushed scans history for all LFS pointers which have been added but not
@@ -191,7 +210,7 @@ func (s *GitScanner) ScanIndex(ref string, cb GitScannerFoundPointer) error {
 	if err != nil {
 		return err
 	}
-	return scanIndex(callback, ref, s.Filter, s.cfg.OSEnv())
+	return scanIndex(callback, ref, s.Filter, s.cfg.GitEnv(), s.cfg.OSEnv())
 }
 
 func (s *GitScanner) opts(mode ScanningMode) *ScanRefsOptions {
